==> haskell-warp-tls-3.2.8-9-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-warp-tls.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: warp-tls
version: 3.2.8
id: warp-tls-3.2.8-DNaxoamr1rVKFKLOSPD92u
key: warp-tls-3.2.8-DNaxoamr1rVKFKLOSPD92u
license: MIT
maintainer: michael@snoyman.com
author: Michael Snoyman
stability: Stable
homepage: http://github.com/yesodweb/wai
synopsis: HTTP over TLS support for Warp via the TLS package
description:
    SSLv1 and SSLv2 are obsoleted by IETF.
    We should use TLS 1.2 (or TLS 1.1 or TLS 1.0 if necessary).
    HTTP/2 can be negotiated by ALPN.
    API docs and the README are available at
    <http://www.stackage.org/package/warp-tls>.
category: Web, Yesod
abi: 0800cdc4d39d1ffe7d926f79505665cc
exposed: True
exposed-modules:
    Network.Wai.Handler.WarpTLS
import-dirs: /usr/lib/ghc-8.6.5/site-local/warp-tls-3.2.8
library-dirs: /usr/lib/ghc-8.6.5/site-local/warp-tls-3.2.8
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/warp-tls-3.2.8
hs-libraries: HSwarp-tls-3.2.8-DNaxoamr1rVKFKLOSPD92u
depends:
    base-4.12.0.0 bytestring-0.10.8.2
    cryptonite-0.26-3rNbQlBz8Bk2f3GtKAwmMo
    data-default-class-0.1.2.0-1aigY0ifYUs4kfvMygEld7
    network-2.8.0.0-GWaLTJJGEavAfd7Abho21R
    streaming-commons-0.2.1.1-28hNvoSsYHXJrd00KOHsX9
    tls-1.4.1-GpNuz7CG7T6EQt34k1sqzH
    tls-session-manager-0.0.1.0-GNuLKQbx7Bm5G60zIcD8AF
    wai-3.2.2.1-Cf1QznwLY1e38bxndDSCcE
    warp-3.3.1-C3xvBghDScwKFhRchvOCIW
haddock-interfaces: /usr/share/doc/haskell-warp-tls/html/warp-tls.haddock
haddock-html: /usr/share/doc/haskell-warp-tls/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-warp-tls-3.2.8-13-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-warp-tls.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: warp-tls
version: 3.2.8
id: warp-tls-3.2.8-5GDJdWcCLVo4yu6IaRMejc
key: warp-tls-3.2.8-5GDJdWcCLVo4yu6IaRMejc
license: MIT
maintainer: michael@snoyman.com
author: Michael Snoyman
stability: Stable
homepage: http://github.com/yesodweb/wai
synopsis: HTTP over TLS support for Warp via the TLS package
description:
    SSLv1 and SSLv2 are obsoleted by IETF.
    We should use TLS 1.2 (or TLS 1.1 or TLS 1.0 if necessary).
    HTTP/2 can be negotiated by ALPN.
    API docs and the README are available at
    <http://www.stackage.org/package/warp-tls>.
category: Web, Yesod
abi: c0d74a32a8dcbd5965cf7f30cc16c9a8
exposed: True
exposed-modules:
    Network.Wai.Handler.WarpTLS
import-dirs: /usr/lib/ghc-8.6.5/site-local/warp-tls-3.2.8
library-dirs: /usr/lib/ghc-8.6.5/site-local/warp-tls-3.2.8
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/warp-tls-3.2.8
hs-libraries: HSwarp-tls-3.2.8-5GDJdWcCLVo4yu6IaRMejc
depends:
    base-4.12.0.0 bytestring-0.10.8.2
    cryptonite-0.26-3rNbQlBz8Bk2f3GtKAwmMo
    data-default-class-0.1.2.0-1aigY0ifYUs4kfvMygEld7
    network-2.8.0.0-GWaLTJJGEavAfd7Abho21R
    streaming-commons-0.2.1.1-28hNvoSsYHXJrd00KOHsX9
    tls-1.4.1-GpNuz7CG7T6EQt34k1sqzH
    tls-session-manager-0.0.1.0-6RV16IaFNsr3TEUh7jNz1D
    wai-3.2.2.1-Cf1QznwLY1e38bxndDSCcE
    warp-3.3.3-73vpEJmYmMdFqcD57mBuga
haddock-interfaces: /usr/share/doc/haskell-warp-tls/html/warp-tls.haddock
haddock-html: /usr/share/doc/haskell-warp-tls/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
